@@ -22,22 +22,27 @@ import argparse
 import json
 import logging
 import os
+import pkgutil
 import sys
 
 import angus
 import angus.cloud
-import version
+import angus.rest
+import angus.version
 
-__version__ = version.__version__
-__updated__ = "2015-06-08"
+
+__path__ = pkgutil.extend_path(__path__, __name__)
+
+__version__ = angus.version.__version__
+__updated__ = "2016-11-30"
 __author__ = "Aurélien Moreau"
-__copyright__ = "Copyright 2015, Angus.ai"
+__copyright__ = "Copyright 2015-2016, Angus.ai"
 __credits__ = ["Aurélien Moreau", "Gwennael Gate"]
 __license__ = "Apache v2.0"
 __maintainer__ = "Aurélien Moreau"
 __status__ = "Production"
 
-logger = logging.getLogger('AnguSDK')
+logger = logging.getLogger('AngusSDK')
 
 
 def parse_cmd_line(argv):
@@ -127,5 +132,12 @@ def get_default_configuration(argv=""):
     return conf
 
 
-def connect(url=None, conf=None):
+def connect(url=None, conf=None, client_id=None,
+            access_token=None, verify=True):
+    if None not in [client_id, access_token]:
+        conf = angus.rest.Configuration()
+        conf.set_credential(client_id, access_token)
+        if not verify:
+            conf.do_not_verify()
+
     return angus.cloud.Root(url, conf)
