@@ -27,7 +27,7 @@ import requests
 import requests_futures.sessions
 import logging
 
-__updated__ = "2016-11-30"
+__updated__ = "2016-12-02"
 __author__ = "Aurélien Moreau"
 __copyright__ = "Copyright 2015-2016, Angus.ai"
 __credits__ = ["Aurélien Moreau", "Gwennael Gate"]
@@ -139,7 +139,7 @@ class Collection(Resource):
 
         if self.conf.executor._work_queue.qsize() > self.conf.executor._max_workers:
             logger.warn("There are too many requests awaiting to "
-            "be sent. This request will be ignored. Please try to decrease "
+            "be sent. This request will be added to the queue but please try to decrease "
             "the rate at which \"process\" is called.")
 
 
